Classical Lomb-Scargle and FFT
======================================

Using the classes presented below, several periodograms can be
calculated:

  * :class:`Fourier transform <PyAstronomy.pyTiming.pyPeriod.Fourier>`
  * :class:`Lomb Scargle <PyAstronomy.pyTiming.pyPeriod.LombScargle>`

All the presented classes inherit from the PeriodBase
class.

.. currentmodule:: PyAstronomy.pyTiming.pyPeriod

The Fourier Transform
------------------------------------------

.. autoclass:: Fourier
   :members:
   :inherited-members:


The Lomb-Scargle-Periodogram (*fast*)
------------------------------------------

.. autoclass:: LombScargle
   :members:
   :inherited-members:

